@@ -1,4 +1,4 @@
-//@line 39 "/home/gscrivano/icecat/icecat-3.5.2-bin/browser/components/preferences/advanced.js"
+//@line 39 "/icecat-3.5.6/browser/components/preferences/advanced.js"
 
 // Load DownloadUtils module for convertByteUnits
 Components.utils.import("resource://gre/modules/DownloadUtils.jsm");
@@ -19,12 +19,11 @@ var gAdvancedPane = {
       advancedPrefs.selectedTab = document.getElementById(extraArgs["advancedTab"]);
     } else {
       var preference = document.getElementById("browser.preferences.advanced.selectedTabIndex");
-      if (preference.value === null)
-        return;
-      advancedPrefs.selectedIndex = preference.value;
+      if (preference.value !== null)
+        advancedPrefs.selectedIndex = preference.value;
     }
 
-//@line 69 "/home/gscrivano/icecat/icecat-3.5.2-bin/browser/components/preferences/advanced.js"
+//@line 68 "/icecat-3.5.6/browser/components/preferences/advanced.js"
     this.updateOfflineApps();
   },
 
@@ -358,7 +357,7 @@ var gAdvancedPane = {
    *             iii 0/1/2   t         true   
    * 
    */
-//@line 500 "/home/gscrivano/icecat/icecat-3.5.2-bin/browser/components/preferences/advanced.js"
+//@line 499 "/icecat-3.5.6/browser/components/preferences/advanced.js"
 
   /**
    * The Extensions checkbox and button are disabled only if the enable Addon
@@ -428,7 +427,7 @@ var gAdvancedPane = {
                                         "chrome://pippki/content/device_manager.xul",
                                         "", null);
   }
-//@line 570 "/home/gscrivano/icecat/icecat-3.5.2-bin/browser/components/preferences/advanced.js"
+//@line 569 "/icecat-3.5.6/browser/components/preferences/advanced.js"
   ,
 
   // SYSTEM DEFAULTS
@@ -474,5 +473,5 @@ var gAdvancedPane = {
       psvc.alert(window, promptTitle, promptMessage);
     }
   }
-//@line 616 "/home/gscrivano/icecat/icecat-3.5.2-bin/browser/components/preferences/advanced.js"
+//@line 615 "/icecat-3.5.6/browser/components/preferences/advanced.js"
 };
