@@ -1,4 +1,4 @@
-//@line 40 "/home/gscrivano/icecat/351/toolkit/content/customizeToolbar.js"
+//@line 40 "/icecat-3.5.6/toolkit/content/customizeToolbar.js"
 
 const kRowMax = 4;
 
@@ -180,7 +180,7 @@ function wrapToolbarItems()
       for (var k = 0; k < toolbar.childNodes.length; ++k) {
         var item = toolbar.childNodes[k];
 
-//@line 225 "/home/gscrivano/icecat/351/toolkit/content/customizeToolbar.js"
+//@line 225 "/icecat-3.5.6/toolkit/content/customizeToolbar.js"
 
         if (isToolbarItem(item)) {
           var wrapper = wrapToolbarItem(item);
@@ -740,6 +740,7 @@ var toolbarDNDObserver =
 
       var direction = window.getComputedStyle(dropTarget.parentNode, null).direction;
       var dropTargetCenter = dropTarget.boxObject.x + (dropTarget.boxObject.width / 2);
+      var dragAfter;
       if (direction == "ltr")
         dragAfter = aEvent.clientX > dropTargetCenter;
       else
